@@ -10,6 +10,6 @@ fn main() {
     Command::new("make").args(["-C", "c"]).status().unwrap();
     println!(r"cargo:rustc-link-search=c/src");
     println!(r"cargo:rustc-link-search=c/lib");
-    println!(r"cargo:rustc-link-lib=gnu");
+    println!(r"cargo:rustc-link-lib=static=gnu");
     println!(r"cargo:rerun-if-changed=c/src/ctype.c");
 }
